function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { Platform, Pressable, StyleSheet, TextInput, View } from 'react-native';
import React, { useMemo, useRef } from 'react';
import Animated, { interpolate, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';

const App = props => {
  const labelSharedValue = useSharedValue(0);
  const {
    textInputProps,
    labelTopValue = -24,
    borderColor = 'gray',
    borderWidth = 1,
    paddingVertical = 8,
    borderRadius = 5,
    placeholder = 'Email',
    value = '',
    onChangeText
  } = props;
  const inputRef = useRef(null);
  const animatedLabelProps = useAnimatedStyle(() => {
    return {
      fontSize: withTiming(interpolate(labelSharedValue.value, [0, 1], [16, 12])),
      top: withTiming(interpolate(labelSharedValue.value, [0, 1], [0, labelTopValue]))
    };
  });
  const styles = useMemo(() => StyleSheet.create({
    textInput: {
      paddingVertical: paddingVertical,
      justifyContent: 'center',
      borderWidth: borderWidth,
      borderRadius: borderRadius,
      borderColor: borderColor
    },
    textInputStyle: {
      fontSize: 16,
      paddingHorizontal: 10,
      paddingBottom: Platform.OS === 'ios' ? 8.3 / 2 : 0,
      paddingVertical: Platform.OS === 'ios' ? 8.3 / 2 : 0,
      textAlignVertical: 'center',
      width: '100%'
    },
    textInputLabelWrapper: {
      position: 'absolute',
      left: 10,
      zIndex: 10,
      bottom: 0,
      top: 0,
      justifyContent: 'center'
    }
  }), [borderColor, borderRadius, borderWidth, paddingVertical]);

  const labelHandler = () => {
    var _inputRef$current;

    labelSharedValue.value = 1;
    inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.focus();
  };

  return /*#__PURE__*/React.createElement(View, {
    style: styles.textInput
  }, /*#__PURE__*/React.createElement(TextInput, _extends({}, textInputProps, {
    ref: inputRef,
    onFocus: () => labelSharedValue.value = 1,
    onBlur: () => {
      if (!value) labelSharedValue.value = 0;
    },
    value: value,
    onChangeText: onChangeText,
    style: [styles.textInputStyle]
  })), /*#__PURE__*/React.createElement(Animated.View, {
    style: styles.textInputLabelWrapper
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: labelHandler
  }, /*#__PURE__*/React.createElement(Animated.Text, {
    style: [animatedLabelProps, {
      backgroundColor: 'white',
      paddingHorizontal: 2
    }]
  }, placeholder))));
};

export default App;
//# sourceMappingURL=index.js.map